;;; color-theme.el --- preview and install color themes

;; Copyright (C) 1999, 2000  Jonadab the Unsightly One <jonadab@bright.net>

;; Author: Jonadab the Unsightly One <jonadab@bright.net>
;; Maintainer: Alex Schroeder <alex@gnu.org>
;; Version: 4.0.0
;; Keywords: faces

;; This file is not part of GNU Emacs.

;; This is free software; you can redistribute it and/or modify it under
;; the terms of the GNU General Public License as published by the Free
;; Software Foundation; either version 2, or (at your option) any later
;; version.

;; This is distributed in the hope that it will be useful, but WITHOUT
;; ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
;; FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
;; for more details.

;; You should have received a copy of the GNU General Public License
;; along with GNU Emacs; see the file COPYING.  If not, write to the
;; Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
;; MA 02111-1307, USA.

;;; Commentary:

;; Sharing your current color setup:

;; If you have already invested time in customizing Emacs faces, please
;; consider sharing your current setup.  Make sure that color-theme.el
;; is in your `load-path'.  Type M-x load-library RET color-theme RET to
;; load all the functions.  Type M-x color-theme-print RET and mail the
;; result to the maintainer of this package (see above for mail addres).

;; If you want to make sure that all your customization was exported,
;; type M-x list-faces-display RET to get a list of all faces currently
;; defined.  This is the list of faces that `color-theme-print' uses.

;; Previewing and installing a color theme:

;; Make sure that color-theme.el is in your `load-path'.  Type M-x
;; load-library RET color-theme RET to load all the functions.

;; The main function to call is color-theme-select.  Type M-x
;; color-theme-select RET.  That creates a Color Theme Selection buffer
;; for selecting a theme to preview.  Press RET on a color theme to
;; preview it.  Press `i' to install the color theme for the rest of
;; your session.

;; If you want to install the color theme as soon as Emacs is started
;; up, read the description of the theme you like and remember the name
;; of the color theme function.  Press `d' on a color theme in the Color
;; Theme Selection buffer to read the description.

;; Assuming you like the Gnome2 theme, add the following to the end of
;; your .emacs (removing the leading `;;').

;; (require 'color-theme)
;; (color-theme-gnome2)

;; Deriving your own color theme:

;; If you want to derive your own color theme from an existing color
;; theme, press `p' in the Color Theme Selection buffer (it doesn't
;; matter where in the buffer you press `p'.  This creates a buffer with
;; the elisp code needed to install the current color theme.  Copy the
;; entire code to your .emacs and start fooling around with it.  Read
;; the documentation of color-theme-install using C-h f
;; color-theme-install RET.

;; Note that all color theme previews are cumulative.  You can try to
;; combine several color themes.  This makes sense if one color theme
;; defines faces which another color theme does not.  Install both
;; themes by pressing `i' on them in the Color Theme Selection buffer,
;; press `p' to get the elisp code, paste it into your .emacs and start
;; working on your masterpiece.

;; Changing menu colors:

;; If are using X, you can set the menu foreground and background using
;; your .Xdefaults file.  If you set emacs*Background and
;; emacs*Foreground, the first frame will be created with these
;; foreground and background colors used for the menu.  If your .emacs
;; loads a color theme, the frame foreground and background colors
;; overwrite the settings from the .Xdefaults file in the frame itself,
;; but not for the menu.  This assumes that you are not setting any menu
;; ressources for Emacs in the .Xdefaults file.  Here is a sample entry
;; for your .Xdefaults file:
;;   emacs*Background:		DarkSlateGray
;;   emacs*Foreground:		wheat

;;; Bugs:

;; Probably XEmacs incompatible; contributions welcome.
;; Not compatible with the forthcoming themes code for Emacs 21.



;;; Code:

(defvar color-theme-buffer-name "*Color Theme Selection*"
  "Name of the color theme selection buffer.")

(defvar color-theme-mode-map
  (let ((map (make-sparse-keymap)))
    (define-key map (kbd "RET") 'color-theme-preview-at-point)
    (define-key map (kbd "c") 'list-color-display)
    (define-key map (kbd "d") 'color-theme-describe)
    (define-key map (kbd "f") 'list-faces-display)
    (define-key map (kbd "i") 'color-theme-install-at-point)
    (define-key map (kbd "p") 'color-theme-print)
    (define-key map (kbd "q") 'bury-buffer)
    (define-key map (kbd "?") 'color-theme-describe)
    (define-key map [mouse-2] 'color-theme-preview-at-mouse)
    (define-key map [S-mouse-2] 'color-theme-install-at-mouse)
    map)
  "Mode map used for the buffer created by `color-theme-select'.")

(defvar color-theme-legal-frame-parameters "\\(color\\|mode\\)$"
  "Regexp that matches frame parameter names.
Only frame parameter names that match this regexp can be changed as part
of a color theme.")

(defvar color-theme-backup nil
  "Original color theme used before any other color theme was installed.
See `color-theme-install' for more information on the theme data structure.
See `color-theme-uninstall' for more information about the use if this 
variable.  This variable is set by `color-theme-store-backup'.")

;;; Selection of a color-theme

(defun color-theme-select ()
  "Displays a special buffer for selecting and installing a color theme."
  (interactive)
  (switch-to-buffer (get-buffer-create color-theme-buffer-name))
  (setq buffer-read-only nil)
  (erase-buffer)
  (let ((uninstall "Uninstall               Restore original colors"))
    (put-text-property 0 (length uninstall) 'color-theme 'color-theme-uninstall uninstall)
    (put-text-property 0 9 'face 'bold uninstall)
    (put-text-property 0 9 'mouse-face 'highlight uninstall)
    (insert uninstall)
    (newline 2))
  (let ((themes color-themes))
    (while themes
      (let* ((theme (car themes))
	     (func (nth 0 theme))
	     (name (nth 1 theme))
	     (author (nth 2 theme)))
	(setq desc (format "%-23s %s" name author))
	(put-text-property 0 (length desc) 'color-theme func desc)
	(put-text-property 0 (length name) 'face 'bold desc)
	(put-text-property 0 (length name) 'mouse-face 'highlight desc)
        (insert desc)
	(newline))
      (setq themes (cdr themes))))
  (beginning-of-buffer)
  (setq buffer-read-only t)
  (set-buffer-modified-p nil)
  (color-theme-mode))

(defun color-theme-mode ()
  "Major mode to select and preview color themes.

Use \\[color-theme-install-at-point] to install a color theme in the current frame
for the current session.  Note that the changes are applied on top of
your current setup.  This is a feature.  If you want to start with a
clean setup, choose the uninstall entry or use \\[color-theme-uninstall].  
See `color-theme-uninstall' about the limitations of the uninstall.

\\{color-theme-mode-map}

Note that some of the themes should be considered extensions to the
standard color theme; they modify only a limited number of faces.  To
verify the final look of a color theme, preview the standard color
theme, then preview the other color theme.  This is a feature; it allows
you to mix several color themes.

If you want to install a color theme permanently, use \\[color-theme-print] 
and copy the result into your .emacs file or put the call to the color
theme function into your .emacs.  See `color-theme-print' for more information.

Note that the Emacs menu is not affected by color themes within Emacs.
Depending on the toolkit you used to compile Emacs, you might have to
set specific X ressources.  See the info manual for more information.

The color themes are listed in `color-themes', which see."
  (kill-all-local-variables)
  (setq major-mode 'color-theme-mode)
  (setq mode-name "Color Themes")
  (use-local-map color-theme-mode-map)
  (goto-address))

;;; Commands in Color Theme Selection mode

(defun color-theme-describe ()
  "Describe color theme listed at point.
This shows the documentation of the value of text-property color-theme
at point.  The text-property color-theme should be a color theme
function.  See `color-themes'."
  (interactive)
  (describe-function (get-text-property (point) 'color-theme)))

(defun color-theme-preview-at-mouse (event)
  "Preview color theme clicked upon using the mouse.
Calls `color-theme-install-at-mouse' with the EVENT argument and
the preview argument."
  (interactive "e")
  (color-theme-install-at-mouse event t))

(defun color-theme-install-at-mouse (event &optional preview)
  "Install color theme clicked upon using the mouse.
First argument EVENT is used to set point.  Then
`color-theme-install-at-point' is called with optional argument PREVIEW.
If PREVIEW is non-nil, the color theme is only previewed."
  (interactive "e")
  (save-excursion
    (let ((posn (event-start event)))
      (set-buffer (window-buffer (posn-window posn)))
      (goto-char (posn-point posn))
      (color-theme-install-at-point preview))))

(defun color-theme-preview-at-point ()
  "Preview color theme at point.
Calls `color-theme-install-at-point' with the preview argument."
  (interactive)
  (color-theme-install-at-point t))

(defun color-theme-install-at-point (&optional preview)
  "Installs color theme at point.
This calls the value of text-property color-theme at point with the
optional PREVIEW argument.  If PREVIEW is non-nil, the color theme is
only previewed.  The text-property color-theme should be a color theme
function.  See `color-themes'."
  (interactive)
  (let ((func (get-text-property (point) 'color-theme)))
    (if func
	(funcall func preview))))

;;; Uninstallation of a color theme, backup creation

(defun color-theme-uninstall (&optional preview)
  "Restore the original color setup.
The original setup is stored in `color-theme-backup'.  The backup
variable is filled by `color-theme-store-backup'.

Note that the backup contains all the faces defined at the time the
backup was created, ie. as the first color theme function runs.  If any
additional faces are installed afterwards, the backup does not contain
any information about them.  You might try `color-theme-standard' to
reset a color theme which you cannot comletely uninstall from your
current session."
  (interactive)
  (if (null color-theme-backup)
      (error "No color theme installed")
    (color-theme-install preview color-theme-backup)))

(defun color-theme-store-backup ()
  "Store original color setup in `color-theme-backup'.
The color setup is generated by `color-theme-snapshot'.  This function
called when `color-theme-install' runs for the first time and
`color-theme-backup' is nil.  The value of `color-theme-backup' is used
in `color-theme-uninstall'."
  (setq color-theme-backup (color-theme-snapshot)))

(defun color-theme-spec (face)
  "Return a list for FACE which has the form (FACE SPEC).
See `defface' for the format of SPEC.  In this case we use only one
DISPLAY, t, and determine ATTS using `face-attr-construct'.
If ATTS is nil, (nil) is used  instead."
  (let ((atts (face-attr-construct face)))
    (if atts
	`(,face ((t ,atts)))
      `(,face ((t (nil)))))))

(defun color-theme-snapshot ()
  "Make a snapshot of the current color theme.
The cons cell returned can be stored in `color-theme-backup'
or used as a parameter to `color-theme-install'."
  (let* ((frame (selected-frame))
	 (backup-frame-param (color-theme-filter-frame-params (frame-parameters frame)))
	 (backup-faces-defs)
	 (faces (face-list))
	 (face))
    ;; Put default face first, therefore default must be the last face
    ;; added to the list.
    (while faces
      (setq face (car faces))
      (setq faces (cdr faces))
      (if (not (eq face 'default))
	  (add-to-list 'backup-faces-defs (color-theme-spec face))))
    (add-to-list 'backup-faces-defs  (color-theme-spec 'default))
    (cons backup-frame-param backup-faces-defs)))

(defun color-theme-filter-frame-params (params)
  "Filter the frame parameters in PARAMS.
The resulting alist only contains keys matching
`color-theme-legal-frame-parameters'."
  (let ((param) (new-params))
    (while params
      (setq param (car params))
      (setq params (cdr params))
      (if (string-match color-theme-legal-frame-parameters (symbol-name (car param)))
	  (add-to-list 'new-params param)))
    new-params))

;;; Installation of a color theme

(defun color-theme-install-frame-parameters (frame parameters)
  "Change frame parameters of frame FRAME using alist PARAMETERS.  
If FRAME is nil, change all frames, `initial-frame-alist', and
`default-frame-alist'.  

Called from `color-theme-install'.  See the elisp manual for more
information on frame parameters.

Example: '((foreground-color . \"white\") (background-color . \"black\"))"
  (let ((params (color-theme-filter-frame-params parameters)))
    (if frame
	(modify-frame-parameters frame params)
      (let ((frames (frame-list)))
	(while frames
	  (setq frame (car frames))
	  (setq frames (cdr frames))
	  (modify-frame-parameters frame params)))
      (setq initial-frame-alist (append params initial-frame-alist)
	    default-frame-alist (append params default-frame-alist)))))

(defun color-theme-install-faces (frame faces)
  "Change faces of frame FRAME using FACES.
If first argument FRAME is nil, change faces for all frames and create
any faces listed in FACES which don't exist.  If first argument FRAME is
non-nil, the faces are only updated for FRAME.  No new faces will be
created.  The modified faces will be marked as \"unchanged from its
standard setting\".  This is OK, since the changes made by installing a 
color theme should never by saved in .emacs by customization code.

FACES should be a list where each entry has the form:

  (FACE SPEC)

See `defface' for the format of SPEC.

Called from `color-theme-install'."
  (while faces
    (let* ((entry (car faces))
	   (face (nth 0 entry))
	   (spec (nth 1 entry)))
      (if (or (facep face)
	      (and (null frame)
		   (make-empty-face face)))
	  (progn
	    (put face 'face-defface-spec spec)
	    (face-spec-set face spec frame)))
      (setq faces (cdr faces)))))
  ;; `custom-set-faces' is unusable here because it doesn't allow to set
  ;; the faces for one frame only.  The NOW parameter was left out
  ;; because the deciding factor is wether FRAME is set or not.  If
  ;; FRAME is nil, then the face is created and marked as a customized
  ;; face.  This is achieved by setting the face-defface-spec property.
  ;; If we don't put some sort of property to the faces, new frames will
  ;; not be created using the face we installed because `face-spec-set'
  ;; is broken: If given a FRAME of nil, it will not set the default
  ;; faces; instead it will walk through all the frames and set modify
  ;; the faces.  If we do set a property (saved-face or
  ;; face-defface-spec), `make-frame' will correctly use the faces we
  ;; defined with our color theme.  If we used saved-face,
  ;; `customize-save-customized' will save all the faces installed as
  ;; part of a color-theme in .emacs.

(defun color-theme-install (preview theme)
  "Install a color theme defined by frame parameters and faces.

If first argument PREVIEW is non-nil, the theme is only installed for
the selected frame; all faces already defined are updated.  No new faces
are created.  If first argument PREVIEW is nil, the theme is installed
for all present and future frames; any missing faces are created.  See
`color-theme-install-faces'.

Second argument THEME is a color theme definition.  See below for more
information.

If `color-theme-backup' is nil, a backup of the current color theme is
stored in `color-theme-backup'.  See `color-theme-store-backup'.

If you want to install a color theme from your .emacs, use the output
generated by `color-theme-print'.  This produces a call to
color-theme-install which you can copy to your .emacs.

A color theme definition is a cons cell 
\(FRAME-PARAMETERS-ALIST . FACE-DEFINITION-ALIST).

FRAME-PARAMETERS-ALIST is an alist of frame parameters.  These are
installed with `color-theme-install-frame-parameters'.

FACE-DEFINITION-ALIST is an alist of face definitions.  These are
installed with `color-theme-install-faces'.

Note that the notation (a . (b c)) is equivalent to (a b c) -- the car
of this list is a and the cdr is (b c).  Color theme definitions are
usually written using the second style."
  (if (null color-theme-backup)
      (color-theme-store-backup))
  (let ((frame (if preview (selected-frame))))
    (color-theme-install-frame-parameters frame (car theme))
    (color-theme-install-faces frame (cdr theme))))

(defun color-theme-print ()
  "Print the current color theme so you can contribute it to
<URL:news:gnu.emacs.sources> or paste it into your .emacs file.

If you want to use a specific color theme function, you can call the
color theme function in your .emacs directly.

Example: \(require 'color-theme)
         \(color-theme-gnome2)"
  (interactive)
  (message "Pretty printing current color theme...")
  (switch-to-buffer (get-buffer-create "*Color Theme*"))
  (setq buffer-read-only nil)
  (erase-buffer)
  (pp `(color-theme-install nil (quote ,(color-theme-snapshot))) (current-buffer))
  (emacs-lisp-mode)
  (message "Pretty printing current color theme... done"))



;;; List of color themes

(defvar color-themes
  '((color-theme-billw "Billw" "Bill White <billw@wolfram.com>")
    (color-theme-simple-1 "Black" "Jonadab <jonadab@bright.net>")
    (color-theme-fischmeister "Fischmeister" 
			      "Sebastian Fischmeister <sfischme@nexus.lzk.tuwien.ac.at>")
    (color-theme-gnome "Gnome" "Jonadab <jonadab@bright.net>")
    (color-theme-gnome2 "Gnome 2" "Alex <a.schroeder@bsiag.ch>")
    (color-theme-jonadabian "Jonadab" "Jonadab <jonadab@bright.net>")
    (color-theme-retro-green "Retro Green" "Alex <a.schroeder@bsiag.ch>")
    (color-theme-retro-orange "Retro Orange" "Alex <a.schroeder@bsiag.ch>")
    (color-theme-ryerson "Ryerson" "Luis Fernandes <elf@ee.ryerson.ca>")
    (color-theme-sitaramv-nt "Sitaram NT"
			     "Sitaram Venkatraman <sitaramv@loc251.tandem.com>")
    (color-theme-sitaramv-solaris "Sitaram Solaris"
				  "Sitaram Venkatraman <sitaramv@loc251.tandem.com>")
    (color-theme-standard "Standard" "Emacs Team, added by Alex <a.schroeder@bsiag.ch>")
    (color-theme-wheat "Wheat" "Alex <a.schroeder@bsiag.ch>"))
  "List of color themes.  

Each THEME is itself a three element list (FUNC NAME MAINTAINER).  

FUNC is a color theme function which does the setup.  The function FUNC
must accept a PREVIEW parameter and call `color-theme-install', passing
PREVIEW along.  The color theme function can be interactive.

NAME is the name of the theme and MAINTAINER is the name and/or email of
the maintainer of the theme.

If you defined your own color theme and want to add it to this list,
use this:

  (add-to-list 'color-themes '(color-theme-gnome2 \"Gnome2\" \"Alex\"))")

(defun color-theme-gnome (&optional preview)
  "Wheat on darkslategrey scheme
from one version of Emacs in RH6 and Gnome, modified by Jonadab."
  (interactive)
  (color-theme-install preview
   '(((foreground-color . "wheat")
      (background-color . "darkslategrey")
      (background-mode . 'dark)) 
     (default ((t (nil))))
     (region ((t (:foreground "cyan" :background "dark cyan"))))
     (underline ((t (:foreground "yellow" :underline))))
     (modeline ((t (:foreground "dark cyan" :background "wheat"))))
     (italic ((t (:foreground "dark red" :italic))))
     (bold-italic ((t (:foreground "dark red" :bold :italic))))
     (font-lock-comment-face ((t (:foreground "Firebrick"))))
     (bold ((t (:bold)))))))

(defun color-theme-gnome2 (&optional preview)
  "Wheat on darkslategrey scheme.  `color-theme-gnome' started it all.
On my NT Emacs with a true color display it looks very somber and dark.
On my Linux I only get to choose from 64 colors and it looks Ok -- I
suffer much less from my flickering monitor.  If you are using this
color theme and have some additional faces to add for modes I don't use,
please share them with me!

This theme supports standard faces, font-lock, eshell, info, message,
gnus, custom, widget, diary, cperl, and erc.  Note that the erc faces
have to be created when the color theme is installed because erc 1.1
doesn't use defface to create faces (yet)."
  (interactive)
  (color-theme-install preview
   '(((foreground-color . "wheat")
      (background-color . "darkslategrey")
      (cursor-color . "LightGray")
      (mouse-color . "Grey")
      (background-mode . 'dark))
     (default ((t (nil))))
     (bold ((t (:bold t))))
     (italic ((t (:italic t))))
     (bold-italic ((t (:foreground "beige" :bold t :italic t))))
     (underline ((t (:underline t))))
     (region ((t (:foreground "cyan" :background "dark cyan"))))
     (highlight ((t (:foreground "DarkGreen" :background "PaleGreen"))))
     (secondary-selection ((t (:foreground "SlateBlue" :background "Aquamarine"))))
     (show-paren-match-face ((t (:foreground "SlateBlue" :background "Aquamarine"))))
     (show-paren-mismatch-face ((t (:foreground "White" :background "Red"))))
     (modeline ((t (:foreground "wheat" :background "DarkOliveGreen"))))
     (diary-face ((t (:foreground "IndianRed"))))
     (calendar-today-face ((t (:foreground "IndianRed" :underline t))))
     (holiday-face ((t (:background "DimGray"))))
     (font-lock-keyword-face ((t (:foreground "Salmon"))))
     (font-lock-type-face ((t (:foreground "YellowGreen"))))
     (font-lock-comment-face ((t (:foreground "IndianRed"))))
     (font-lock-function-name-face ((t (:foreground "Aquamarine"))))
     (font-lock-variable-name-face ((t (:foreground "Aquamarine"))))
     (font-lock-builtin-face ((t (:foreground "PaleGreen"))))
     (font-lock-warning-face ((t (:foreground "IndianRed" :bold t))))
     (font-lock-string-face ((t (:foreground "LightSalmon"))))
     (font-lock-constant-face ((t (:foreground "Aquamarine"))))
     (cperl-array-face ((t (:foreground "Yellow"))))
     (cperl-hash-face ((t (:foreground "White"))))
     (cperl-nonoverridable-face ((t (:foreground "SkyBlue"))))
     (eshell-ls-directory-face ((t (:foreground "MediumSlateBlue" :bold t))))
     (eshell-ls-symlink-face ((t (:foreground "White"))))
     (eshell-ls-executable-face ((t (:foreground "Coral"))))
     (eshell-ls-readonly-face ((t (:foreground "Aquamarine"))))
     (eshell-ls-unreadable-face ((t (:foreground "DimGray"))))
     (eshell-ls-special-face ((t (:foreground "Gold"))))
     (eshell-ls-archive-face ((t (:foreground "IndianRed" :bold t))))
     (eshell-ls-backup-face ((t (:foreground "Grey"))))
     (eshell-ls-picture-face ((t (:foreground "Violet"))))
     (eshell-ls-clutter-face ((t (:foreground "DimGray"))))
     (eshell-ls-product-face ((t (:foreground "LightSalmon"))))
     (eshell-ls-missing-face ((t (:foreground "black"))))
     (eshell-prompt-face ((t (:foreground "MediumAquamarine"))))
     (info-node ((t (:foreground "DodgerBlue1" :bold t :underline t))))
     (info-xref ((t (:foreground "DodgerBlue1" :underline t))))
     (message-header-to-face ((t (:foreground "light cyan" :bold t))))
     (message-header-cc-face ((t (:foreground "light cyan"))))
     (message-header-subject-face ((t (:foreground "light cyan" :bold t))))
     (message-header-newsgroups-face ((t (:foreground "MediumAquamarine" :bold t :italic t))))
     (message-header-other-face ((t (:foreground "MediumAquamarine"))))
     (message-header-name-face ((t (:foreground "LightBlue"))))
     (message-header-xheader-face ((t (:foreground "MediumAquamarine"))))
     (message-separator-face ((t (:foreground "chocolate"))))
     (gnus-header-content-face ((t (:foreground "LightSkyBlue3"))))
     (gnus-header-from-face ((t (:foreground "light cyan" :bold t))))
     (gnus-header-name-face ((t (:foreground "LightBlue" :bold t))))
     (gnus-header-newsgroups-face ((t (:foreground "MediumAquamarine" :bold t :italic t))))
     (gnus-header-subject-face ((t (:foreground "light cyan" :bold t))))
     (message-cited-text-face ((t (:foreground "LightSalmon"))))
     (gnus-cite-face-1 ((t (:foreground "LightSalmon"))))
     (gnus-cite-face-2 ((t (:foreground "Khaki"))))
     (gnus-cite-face-3 ((t (:foreground "Coral"))))
     (gnus-cite-face-4 ((t (:foreground "yellow green"))))
     (gnus-cite-face-5 ((t (:foreground "IndianRed"))))
     (gnus-signature-face ((t (:foreground "Grey"))))
     (gnus-group-news-1-face ((t (:foreground "White" :bold t))))
     (gnus-group-mail-1-face ((t (:foreground "White" :bold t))))
     (gnus-group-news-1-empty-face ((t (:foreground "White"))))
     (gnus-group-mail-1-empty-face ((t (:foreground "White"))))
     (gnus-group-news-2-face ((t (:foreground "light cyan" :bold t))))
     (gnus-group-mail-2-face ((t (:foreground "light cyan" :bold t))))
     (gnus-group-news-2-empty-face ((t (:foreground "light cyan"))))
     (gnus-group-mail-2-empty-face ((t (:foreground "light cyan"))))
     (gnus-group-news-3-face ((t (:foreground "LightBlue" :bold t))))
     (gnus-group-mail-3-face ((t (:foreground "LightBlue" :bold t))))
     (gnus-group-news-3-empty-face ((t (:foreground "LightBlue"))))
     (gnus-group-mail-3-empty-face ((t (:foreground "LightBlue"))))
     (gnus-group-mail-low-face ((t (:foreground "Aquamarine" :bold t))))
     (gnus-group-mail-low-empty-face ((t (:foreground "Aquamarine"))))
     (gnus-group-news-4-face ((t (:foreground "Aquamarine" :bold t))))
     (gnus-group-news-4-empty-face ((t (:foreground "Aquamarine"))))
     (gnus-group-news-5-face ((t (:foreground "MediumAquamarine" :bold t))))
     (gnus-group-news-5-empty-face ((t (:foreground "MediumAquamarine"))))
     (gnus-group-news-6-face ((t (:foreground "MediumAquamarine" :bold t))))
     (gnus-group-news-6-empty-face ((t (:foreground "MediumAquamarine"))))
     (gnus-group-news-low-face ((t (:foreground "MediumAquamarine" :bold t))))
     (gnus-group-news-low-empty-face ((t (:foreground "MediumAquamarine"))))
     (gnus-summary-selected-face ((t (:underline t))))
     (gnus-summary-cancelled-face ((t (:foreground "Yellow" :background "Black"))))
     (gnus-summary-high-ancient-face ((t (:foreground "MediumAquamarine" :bold t))))
     (gnus-summary-high-read-face ((t (:foreground "Aquamarine" :bold t))))
     (gnus-summary-high-ticked-face ((t (:foreground "LightSalmon" :bold t))))
     (gnus-summary-high-unread-face ((t (:foreground "beige" :bold t :italic t))))
     (gnus-summary-low-ancient-face ((t (:foreground "DimGray" :italic t))))
     (gnus-summary-low-read-face ((t (:foreground "Grey"))))
     (gnus-summary-low-ticked-face ((t (:foreground "Pink"))))
     (gnus-summary-low-unread-face ((t (:foreground "LightGray"))))
     (gnus-summary-normal-ancient-face ((t (:foreground "MediumAquamarine"))))
     (gnus-summary-normal-read-face ((t (:foreground "Aquamarine"))))
     (gnus-summary-normal-ticked-face ((t (:foreground "LightSalmon"))))
     (gnus-summary-normal-unread-face ((t (nil))))
     (gnus-splash-face ((t (:foreground "ForestGreen"))))
     (custom-button-face ((t (:foreground "MediumSlateBlue" :underline t))))
     (custom-documentation-face ((t (:foreground "Grey"))))
     (custom-group-tag-face ((t (:foreground "MediumAquamarine"))))
     (custom-variable-tag-face ((t (:foreground "Aquamarine"))))
     (custom-state-face ((t (:foreground "LightSalmon"))))
     (widget-field-face ((t (:foreground "LightBlue"))))
     (widget-inactive-face ((t (:foreground "DimGray"))))
     (widget-single-line-field-face ((t (:foreground "LightBlue"))))
     (erc-action-face ((t (:bold t))))
     (erc-bold-face ((t (:bold t))))
     (erc-default-face nil)
     (erc-direct-msg-face ((t (:foreground "LightSalmon"))))
     (erc-error-face ((t (:foreground "IndianRed" :bold t))))
     (erc-input-face nil)
     (erc-inverse-face ((t (:foreground "darkslategrey" :background "wheat"))))
     (erc-notice-face ((t (:foreground "MediumAquamarine"))))
     (erc-pal-face ((t (:foreground "pale green"))))
     (erc-prompt-face ((t (:foreground "MediumAquamarine"))))
     (erc-underline-face ((t (:underline t)))))))

(defun color-theme-simple-1 (&optional preview)
  "Black bg; doesn't mess with most faces, but does turn on dark
background mode."
  (interactive)
  (color-theme-install preview
   '(((foreground-color . "white")
      (background-color . "black")
      (cursor-color     . "indian red")
      (background-mode  . 'dark))
     (default ((t (nil))))
     (modeline ((t (:foreground "black" :background "white"))))
     (underline ((t (:underline t))))
     (region ((t (:background "grey")))))))

(defun color-theme-jonadabian (&optional preview)
  "Dark blue background.
Supports standard faces, font-lock, highlight-changes, widget and
custom."
  (interactive)
  (color-theme-install preview
   '(((foreground-color . "wheat")
      (cursor-color . "medium turquoise")
      (background-color . "#000055")
      (background-mode . 'dark))
     (default ((t (:foreground "#CCBB77" :background "#000055"))))
     (modeline ((t (:foreground "cyan" :background "#007080"))))
     (underline ((t (:underline t))))
     (region ((t (:background "#004080"))))
     (font-lock-keyword-face ((t (:foreground "#00BBBB"))))
     (font-lock-comment-face ((t (:foreground "grey50" :bold t :italic t))))
     (font-lock-string-face ((t (:foreground "#10D010"))))
     (font-lock-constant-face ((t (:foreground "indian red"))))
     (highlight-changes-face ((t (:background "navy"))))
     (highlight-changes-delete-face ((t (:foreground "red" :background "navy"))))
     (widget-field-face ((t (:foreground "black" :background "grey35"))))
     (widget-inactive-face ((t (:foreground "gray"))))
     (custom-button-face ((t (:foreground "yellow" :background "dark blue"))))
     (custom-state-face ((t (:foreground "mediumaquamarine"))))
     (custom-face-tag-face ((t (:foreground "goldenrod" :underline t))))
     (custom-documentation-face ((t (:foreground "#10D010"))))
     (custom-set-face ((t (:foreground "#2020D0")))))))

(defun color-theme-ryerson (&optional preview)
  "White on midnightblue scheme used at Ryerson Polytechnic University
in the Electronic Engineering department."
  (interactive)
  (color-theme-install preview
   '(((foreground-color . "white")
      (background-color . "midnightblue")
      (cursor-color     . "red")
      (background-mode  . 'dark))
     (default ((t (nil))))
     (modeline ((t (:foreground "black" :background "slategray3"))))
     (underline ((t (:underline t))))
     (region ((t (:foreground "black" :background "slategray3")))))))

(defun color-theme-wheat (&optional preview)
  "Default colors on a wheat background.
Calls the standard color theme function `color-theme-standard' in order
to reset all faces."
  (interactive)
  (color-theme-standard preview)
  (color-theme-install-frame-parameters (if preview (selected-frame))
					'((background-color . "Wheat"))))

(defun color-theme-standard (&optional preview)
  "The default colors.  Use this theme to undo it all.
Includes all the faces in the Emacs source created using `defface' as
well as the eshell faces.  This is also a good starting place for
would-be theme authors."
;; In order to produce this, follow these two steps:
;; 1. cd into the Emacs lisp directory and run the following command:
;;    ( for d in `find -type d`; do grep --files-with-matches 'defface[ 	]' $d/*.el; done ) | sort | uniq
;;    Put the result in a lisp block:
;;     (progn
;;       (load-library "calendar")
;;       (load-library "cus-edit")
;;       (load-library "custom")
;;       (load-library "ediff-init")
;;       (load-library "viper-init")
;;       (load-library "enriched")
;;       (load-library "faces")
;;       (load-library "font-lock")
;;       (load-library "gnus-art")
;;       (load-library "gnus-cite")
;;       (load-library "gnus")
;;       (load-library "message")
;;       (load-library "hilit-chg")
;;       (load-library "info")
;;       (load-library "paren")
;;       (load-library "cperl-mode")
;;       (load-library "make-mode")
;;       (load-library "vhdl-mode")
;;       (load-library "speedbar")
;;       (load-library "flyspell")
;;       (load-library "vcursor")
;;       (load-library "wid-edit"))
;;    Repeat this for any directories on your load path which you want to
;;    include in the standard.  This might include W3, eshell, etc.
;;     (progn
;;       (load-library "eshell-test")
;;       (load-library "eshell-prompt")
;;       (load-library "eshell-ls"))
;; 2. Start emacs using the --no-init-file and --no-site-file command line
;;    arguments.  Evaluate the lisp block you prepared.
;; 3. Load color-theme and run color-theme-print.  Save the output and use it 
;;    to define color-theme-standard.
  (interactive)
  (color-theme-install preview
   '(((foreground-color . "black")
      (background-color . "white")
      (mouse-color . "black")
      (cursor-color . "black")
      (border-color . "black")
      (background-mode . light))
     (default ((t (nil))))
     (modeline ((t (:foreground "white" :background "black"))))
     (highlight ((t (:background "darkseagreen2"))))
     (bold ((t (:bold t))))
     (italic ((t (:italic t))))
     (bold-italic ((t (:bold t :italic t))))
     (region ((t (:background "gray"))))
     (secondary-selection ((t (:background "paleturquoise"))))
     (underline ((t (:underline t))))
     (diary-face ((t (:foreground "red"))))
     (calendar-today-face ((t (:underline t))))
     (holiday-face ((t (:background "pink"))))
     (widget-documentation-face ((t (:foreground "dark green"))))
     (widget-button-face ((t (:bold t))))
     (widget-field-face ((t (:background "gray85"))))
     (widget-single-line-field-face ((t (:background "gray85"))))
     (widget-inactive-face ((t (:foreground "dim gray"))))
     (widget-button-pressed-face ((t (:foreground "red"))))
     (custom-invalid-face ((t (:foreground "yellow" :background "red"))))
     (custom-rogue-face ((t (:foreground "pink" :background "black"))))
     (custom-modified-face ((t (:foreground "white" :background "blue"))))
     (custom-set-face ((t (:foreground "blue" :background "white"))))
     (custom-changed-face ((t (:foreground "white" :background "blue"))))
     (custom-saved-face ((t (:underline t))))
     (custom-button-face ((t (nil))))
     (custom-documentation-face ((t (nil))))
     (custom-state-face ((t (:foreground "dark green"))))
     (custom-variable-tag-face ((t (:foreground "blue" :underline t))))
     (custom-variable-button-face ((t (:bold t :underline t))))
     (custom-face-tag-face ((t (:underline t))))
     (custom-group-tag-face-1 ((t (:foreground "red" :underline t))))
     (custom-group-tag-face ((t (:foreground "blue" :underline t))))
     (ediff-current-diff-face-A ((t (:foreground "firebrick" :background "pale green"))))
     (ediff-current-diff-face-B ((t (:foreground "DarkOrchid" :background "Yellow"))))
     (ediff-current-diff-face-C ((t (:foreground "Navy" :background "Pink"))))
     (ediff-current-diff-face-Ancestor ((t (:foreground "Black" :background "VioletRed"))))
     (ediff-fine-diff-face-A ((t (:foreground "Navy" :background "sky blue"))))
     (ediff-fine-diff-face-B ((t (:foreground "Black" :background "cyan"))))
     (ediff-fine-diff-face-C ((t (:foreground "Black" :background "Turquoise"))))
     (ediff-fine-diff-face-Ancestor ((t (:foreground "Black" :background "Green"))))
     (ediff-even-diff-face-A ((t (:foreground "Black" :background "light grey"))))
     (ediff-even-diff-face-B ((t (:foreground "White" :background "Grey"))))
     (ediff-even-diff-face-C ((t (:foreground "Black" :background "light grey"))))
     (ediff-even-diff-face-Ancestor ((t (:foreground "White" :background "Grey"))))
     (ediff-odd-diff-face-A ((t (:foreground "White" :background "Grey"))))
     (ediff-odd-diff-face-B ((t (:foreground "Black" :background "light grey"))))
     (ediff-odd-diff-face-C ((t (:foreground "White" :background "Grey"))))
     (ediff-odd-diff-face-Ancestor ((t (:foreground "Black" :background "light grey"))))
     (viper-search-face ((t (:foreground "Black" :background "khaki"))))
     (viper-replace-overlay-face ((t (:foreground "Black" :background "darkseagreen2"))))
     (viper-minibuffer-emacs-face ((t (:foreground "Black" :background "darkseagreen2"))))
     (viper-minibuffer-insert-face ((t (:foreground "Black" :background "pink"))))
     (viper-minibuffer-vi-face ((t (:foreground "DarkGreen" :background "grey"))))
     (fixed ((t (:bold t))))
     (excerpt ((t (:italic t))))
     (font-lock-comment-face ((t (:foreground "Firebrick"))))
     (font-lock-string-face ((t (:foreground "RosyBrown"))))
     (font-lock-keyword-face ((t (:foreground "Purple"))))
     (font-lock-builtin-face ((t (:foreground "Orchid"))))
     (font-lock-function-name-face ((t (:foreground "Blue"))))
     (font-lock-variable-name-face ((t (:foreground "DarkGoldenrod"))))
     (font-lock-type-face ((t (:foreground "ForestGreen"))))
     (font-lock-constant-face ((t (:foreground "CadetBlue"))))
     (font-lock-warning-face ((t (:foreground "Red" :bold t))))
     (message-header-to-face ((t (:foreground "MidnightBlue" :bold t))))
     (message-header-cc-face ((t (:foreground "MidnightBlue"))))
     (message-header-subject-face ((t (:foreground "navy blue" :bold t))))
     (message-header-newsgroups-face ((t (:foreground "blue4" :bold t :italic t))))
     (message-header-other-face ((t (:foreground "steel blue"))))
     (message-header-name-face ((t (:foreground "cornflower blue"))))
     (message-header-xheader-face ((t (:foreground "blue"))))
     (message-separator-face ((t (:foreground "brown"))))
     (message-cited-text-face ((t (:foreground "red"))))
     (gnus-group-news-1-face ((t (:foreground "ForestGreen" :bold t))))
     (gnus-group-news-1-empty-face ((t (:foreground "ForestGreen"))))
     (gnus-group-news-2-face ((t (:foreground "CadetBlue4" :bold t))))
     (gnus-group-news-2-empty-face ((t (:foreground "CadetBlue4"))))
     (gnus-group-news-3-face ((t (:bold t))))
     (gnus-group-news-3-empty-face ((t (nil))))
     (gnus-group-news-low-face ((t (:foreground "DarkGreen" :bold t))))
     (gnus-group-news-low-empty-face ((t (:foreground "DarkGreen"))))
     (gnus-group-mail-1-face ((t (:foreground "DeepPink3" :bold t))))
     (gnus-group-mail-1-empty-face ((t (:foreground "DeepPink3"))))
     (gnus-group-mail-2-face ((t (:foreground "HotPink3" :bold t))))
     (gnus-group-mail-2-empty-face ((t (:foreground "HotPink3"))))
     (gnus-group-mail-3-face ((t (:foreground "magenta4" :bold t))))
     (gnus-group-mail-3-empty-face ((t (:foreground "magenta4"))))
     (gnus-group-mail-low-face ((t (:foreground "DeepPink4" :bold t))))
     (gnus-group-mail-low-empty-face ((t (:foreground "DeepPink4"))))
     (gnus-summary-selected-face ((t (:underline t))))
     (gnus-summary-cancelled-face ((t (:foreground "yellow" :background "black"))))
     (gnus-summary-high-ticked-face ((t (:foreground "firebrick" :bold t))))
     (gnus-summary-low-ticked-face ((t (:foreground "firebrick" :italic t))))
     (gnus-summary-normal-ticked-face ((t (:foreground "firebrick"))))
     (gnus-summary-high-ancient-face ((t (:foreground "RoyalBlue" :bold t))))
     (gnus-summary-low-ancient-face ((t (:foreground "RoyalBlue" :italic t))))
     (gnus-summary-normal-ancient-face ((t (:foreground "RoyalBlue"))))
     (gnus-summary-high-unread-face ((t (:bold t))))
     (gnus-summary-low-unread-face ((t (:italic t))))
     (gnus-summary-normal-unread-face ((t (nil))))
     (gnus-summary-high-read-face ((t (:foreground "DarkGreen" :bold t))))
     (gnus-summary-low-read-face ((t (:foreground "DarkGreen" :italic t))))
     (gnus-summary-normal-read-face ((t (:foreground "DarkGreen"))))
     (gnus-splash-face ((t (:foreground "ForestGreen"))))
     (gnus-emphasis-bold ((t (:bold t))))
     (gnus-emphasis-italic ((t (:italic t))))
     (gnus-emphasis-underline ((t (:underline t))))
     (gnus-emphasis-underline-bold ((t (:bold t :underline t))))
     (gnus-emphasis-underline-italic ((t (:italic t :underline t))))
     (gnus-emphasis-bold-italic ((t (:bold t :italic t))))
     (gnus-emphasis-underline-bold-italic ((t (:bold t :italic t :underline t))))
     (gnus-signature-face ((t (:italic t))))
     (gnus-header-from-face ((t (:foreground "red3"))))
     (gnus-header-subject-face ((t (:foreground "red4"))))
     (gnus-header-newsgroups-face ((t (:foreground "MidnightBlue" :italic t))))
     (gnus-header-name-face ((t (:foreground "maroon"))))
     (gnus-header-content-face ((t (:foreground "indianred4" :italic t))))
     (gnus-cite-attribution-face ((t (:italic t))))
     (gnus-cite-face-1 ((t (:foreground "MidnightBlue"))))
     (gnus-cite-face-2 ((t (:foreground "firebrick"))))
     (gnus-cite-face-3 ((t (:foreground "dark green"))))
     (gnus-cite-face-4 ((t (:foreground "OrangeRed"))))
     (gnus-cite-face-5 ((t (:foreground "dark khaki"))))
     (gnus-cite-face-6 ((t (:foreground "dark violet"))))
     (gnus-cite-face-7 ((t (:foreground "SteelBlue4"))))
     (gnus-cite-face-8 ((t (:foreground "magenta"))))
     (gnus-cite-face-9 ((t (:foreground "violet"))))
     (gnus-cite-face-10 ((t (:foreground "medium purple"))))
     (gnus-cite-face-11 ((t (:foreground "turquoise"))))
     (highlight-changes-face ((t (:foreground "red"))))
     (highlight-changes-delete-face ((t (:foreground "red" :underline t))))
     (info-node ((t (:bold t :italic t))))
     (info-menu-5 ((t (:underline t))))
     (info-xref ((t (:bold t))))
     (show-paren-match-face ((t (:background "turquoise"))))
     (show-paren-mismatch-face ((t (:foreground "white" :background "purple"))))
     (cperl-nonoverridable-face ((t (:foreground "chartreuse3"))))
     (cperl-array-face ((t (:foreground "Blue" :background "lightyellow2" :bold t))))
     (cperl-hash-face ((t (:foreground "Red" :background "lightyellow2" :bold t :italic t))))
     (makefile-space-face ((t (:background "hotpink"))))
     (vhdl-font-lock-prompt-face ((t (:foreground "Red" :bold t))))
     (vhdl-font-lock-attribute-face ((t (:foreground "Orchid"))))
     (vhdl-font-lock-enumvalue-face ((t (:foreground "Gold4"))))
     (vhdl-font-lock-function-face ((t (:foreground "Orchid4"))))
     (vhdl-font-lock-directive-face ((t (:foreground "CadetBlue"))))
     (vhdl-font-lock-reserved-words-face ((t (:foreground "Orange" :bold t))))
     (vhdl-font-lock-translate-off-face ((t (:background "LightGray"))))
     (vhdl-speedbar-entity-face ((t (:foreground "ForestGreen"))))
     (vhdl-speedbar-architecture-face ((t (:foreground "Blue"))))
     (vhdl-speedbar-configuration-face ((t (:foreground "DarkGoldenrod"))))
     (vhdl-speedbar-package-face ((t (:foreground "Grey50"))))
     (vhdl-speedbar-instantiation-face ((t (:foreground "Brown"))))
     (vhdl-speedbar-entity-selected-face ((t (:foreground "ForestGreen" :underline t))))
     (vhdl-speedbar-architecture-selected-face ((t (:foreground "Blue" :underline t))))
     (vhdl-speedbar-configuration-selected-face ((t (:foreground "DarkGoldenrod" :underline t))))
     (vhdl-speedbar-package-selected-face ((t (:foreground "Grey50" :underline t))))
     (vhdl-speedbar-instantiation-selected-face ((t (:foreground "Brown" :underline t))))
     (speedbar-button-face ((t (:foreground "green4"))))
     (speedbar-file-face ((t (:foreground "cyan4"))))
     (speedbar-directory-face ((t (:foreground "blue4"))))
     (speedbar-tag-face ((t (:foreground "brown"))))
     (speedbar-selected-face ((t (:foreground "red" :underline t))))
     (speedbar-highlight-face ((t (:background "green"))))
     (flyspell-incorrect-face ((t (:foreground "OrangeRed" :bold t :underline t))))
     (flyspell-duplicate-face ((t (:foreground "Gold3" :bold t :underline t))))
     (vcursor ((t (:foreground "blue" :background "cyan" :underline t))))
     (eshell-test-ok-face ((t (:foreground "Green" :bold t))))
     (eshell-test-failed-face ((t (:foreground "OrangeRed" :bold t))))
     (eshell-prompt-face ((t (:foreground "Red" :bold t))))
     (eshell-ls-directory-face ((t (:foreground "Blue" :bold t))))
     (eshell-ls-symlink-face ((t (:foreground "DarkCyan" :bold t))))
     (eshell-ls-executable-face ((t (:foreground "ForestGreen" :bold t))))
     (eshell-ls-readonly-face ((t (:foreground "Brown"))))
     (eshell-ls-unreadable-face ((t (:foreground "Grey30"))))
     (eshell-ls-special-face ((t (:foreground "Magenta" :bold t))))
     (eshell-ls-missing-face ((t (:foreground "Red" :bold t))))
     (eshell-ls-archive-face ((t (:foreground "Orchid" :bold t))))
     (eshell-ls-backup-face ((t (:foreground "OrangeRed"))))
     (eshell-ls-product-face ((t (:foreground "OrangeRed"))))
     (eshell-ls-clutter-face ((t (:foreground "OrangeRed" :bold t)))))))

(defun color-theme-fischmeister (&optional preview)
  "The light colors on a grey blackground.
Sebastian Fischmeister <sfischme@nexus.lzk.tuwien.ac.at>"
  (interactive)
  (color-theme-install preview
   '(((foreground-color . "black")
      (background-color . "gray80")
      (mouse-color . "red")
      (cursor-color . "yellow")
      (border-color . "black")
      (background-mode . light))
     (default ((t (nil))))
     (modeline ((t (:foreground "gray80" :background "black"))))
     (highlight ((t (:background "darkseagreen2"))))
     (bold ((t (:bold t))))
     (italic ((t (:italic t))))
     (bold-italic ((t (:bold t :italic t))))
     (region ((t (:background "gray"))))
     (secondary-selection ((t (:background "paleturquoise"))))
     (underline ((t (:underline t))))
     (show-paren-match-face ((t (:foreground "yellow" :background "darkgreen"))))
     (show-paren-mismatch-face ((t (:foreground "white" :background "red"))))
     (font-lock-comment-face ((t (:foreground "FireBrick" :bold t :italic t))))
     (font-lock-string-face ((t (:foreground "DarkSlateBlue" :italic t))))
     (font-lock-keyword-face ((t (:foreground "navy"))))
     (font-lock-builtin-face ((t (:foreground "white"))))
     (font-lock-function-name-face ((t (:foreground "Blue"))))
     (font-lock-variable-name-face ((t (:foreground "Darkblue"))))
     (font-lock-type-face ((t (:foreground "darkgreen"))))
     (font-lock-constant-face ((t (:foreground "CadetBlue"))))
     (font-lock-warning-face ((t (:foreground "Orchid" :bold t))))
     (font-lock-reference-face ((t (:foreground "SteelBlue")))))))

(defun color-theme-sitaramv-solaris (&optional preview)
  "White on a midnight blue background.  Lots of yellow and orange.
Includes faces for font-lock, widget, custom, speedbar, message, gnus,
eshell."
  (interactive)
  (color-theme-install preview
   '(((foreground-color . "white")
      (background-color . "MidnightBlue")
      (mouse-color . "yellow")
      (cursor-color . "magenta2")
      (border-color . "black")
      (background-mode . dark))
     (default ((t (nil))))
     (modeline ((t (:foreground "black" :background "gold2"))))
     (highlight ((t (:foreground "black" :background "Aquamarine"))))
     (bold ((t (:bold t))))
     (italic ((t (:italic t))))
     (bold-italic ((t (:bold t :italic t))))
     (region ((t (:foreground "black" :background "snow3"))))
     (secondary-selection ((t (:foreground "black" :background "aquamarine"))))
     (underline ((t (:underline t))))
     (lazy-highlight-face ((t (:foreground "yellow"))))
     (font-lock-comment-face ((t (:foreground "orange" :italic t))))
     (font-lock-string-face ((t (:foreground "orange"))))
     (font-lock-keyword-face ((t (:foreground "green"))))
     (font-lock-builtin-face ((t (:foreground "LightSteelBlue"))))
     (font-lock-function-name-face ((t (:foreground "cyan" :bold t))))
     (font-lock-variable-name-face ((t (:foreground "white"))))
     (font-lock-type-face ((t (:foreground "cyan"))))
     (font-lock-constant-face ((t (:foreground "Aquamarine"))))
     (font-lock-warning-face ((t (:foreground "Pink" :bold t))))
     (widget-documentation-face ((t (:foreground "lime green"))))
     (widget-button-face ((t (:bold t))))
     (widget-field-face ((t (:background "dim gray"))))
     (widget-single-line-field-face ((t (:background "dim gray"))))
     (widget-inactive-face ((t (:foreground "light gray"))))
     (widget-button-pressed-face ((t (:foreground "red"))))
     (custom-invalid-face ((t (:foreground "yellow" :background "red"))))
     (custom-rogue-face ((t (:foreground "pink" :background "black"))))
     (custom-modified-face ((t (:foreground "white" :background "blue"))))
     (custom-set-face ((t (:foreground "blue" :background "white"))))
     (custom-changed-face ((t (:foreground "white" :background "blue"))))
     (custom-saved-face ((t (:underline t))))
     (custom-button-face ((t (nil))))
     (custom-documentation-face ((t (nil))))
     (custom-state-face ((t (:foreground "lime green"))))
     (custom-variable-tag-face ((t (:foreground "light blue" :underline t))))
     (custom-variable-button-face ((t (:bold t :underline t))))
     (custom-face-tag-face ((t (:underline t))))
     (custom-group-tag-face-1 ((t (:foreground "pink" :underline t))))
     (custom-group-tag-face ((t (:foreground "light blue" :underline t))))
     (speedbar-button-face ((t (:foreground "green3"))))
     (speedbar-file-face ((t (:foreground "cyan"))))
     (speedbar-directory-face ((t (:foreground "light blue"))))
     (speedbar-tag-face ((t (:foreground "yellow"))))
     (speedbar-selected-face ((t (:foreground "red" :underline t))))
     (speedbar-highlight-face ((t (:background "sea green"))))
     (font-lock-doc-string-face ((t (:foreground "Plum1" :bold t))))
     (font-lock-exit-face ((t (:foreground "green"))))
     (ff-paths-non-existant-file-face ((t (:foreground "NavyBlue" :bold t))))
     (show-paren-match-face ((t (:background "red"))))
     (show-paren-mismatch-face ((t (:foreground "white" :background "purple"))))
     (message-header-to-face ((t (:foreground "green2" :bold t))))
     (message-header-cc-face ((t (:foreground "LightGoldenrod" :bold t))))
     (message-header-subject-face ((t (:foreground "green3"))))
     (message-header-newsgroups-face ((t (:foreground "yellow" :bold t :italic t))))
     (message-header-other-face ((t (:foreground "Salmon"))))
     (message-header-name-face ((t (:foreground "green3"))))
     (message-header-xheader-face ((t (:foreground "GreenYellow"))))
     (message-separator-face ((t (:foreground "Tan"))))
     (message-cited-text-face ((t (:foreground "Gold"))))
     (message-mml-face ((t (:foreground "ForestGreen"))))
     (gnus-group-news-1-face ((t (:foreground "PaleTurquoise" :bold t))))
     (gnus-group-news-1-empty-face ((t (:foreground "PaleTurquoise"))))
     (gnus-group-news-2-face ((t (:foreground "turquoise" :bold t))))
     (gnus-group-news-2-empty-face ((t (:foreground "turquoise"))))
     (gnus-group-news-3-face ((t (:bold t))))
     (gnus-group-news-3-empty-face ((t (nil))))
     (gnus-group-news-4-face ((t (:bold t))))
     (gnus-group-news-4-empty-face ((t (nil))))
     (gnus-group-news-5-face ((t (:bold t))))
     (gnus-group-news-5-empty-face ((t (nil))))
     (gnus-group-news-6-face ((t (:bold t))))
     (gnus-group-news-6-empty-face ((t (nil))))
     (gnus-group-news-low-face ((t (:foreground "DarkTurquoise" :bold t))))
     (gnus-group-news-low-empty-face ((t (:foreground "DarkTurquoise"))))
     (gnus-group-mail-1-face ((t (:foreground "aquamarine1" :bold t))))
     (gnus-group-mail-1-empty-face ((t (:foreground "aquamarine1"))))
     (gnus-group-mail-2-face ((t (:foreground "aquamarine2" :bold t))))
     (gnus-group-mail-2-empty-face ((t (:foreground "aquamarine2"))))
     (gnus-group-mail-3-face ((t (:foreground "aquamarine3" :bold t))))
     (gnus-group-mail-3-empty-face ((t (:foreground "aquamarine3"))))
     (gnus-group-mail-low-face ((t (:foreground "aquamarine4" :bold t))))
     (gnus-group-mail-low-empty-face ((t (:foreground "aquamarine4"))))
     (gnus-summary-selected-face ((t (:underline t))))
     (gnus-summary-cancelled-face ((t (:foreground "yellow" :background "black"))))
     (gnus-summary-high-ticked-face ((t (:foreground "pink" :bold t))))
     (gnus-summary-low-ticked-face ((t (:foreground "pink" :italic t))))
     (gnus-summary-normal-ticked-face ((t (:foreground "pink"))))
     (gnus-summary-high-ancient-face ((t (:foreground "SkyBlue" :bold t))))
     (gnus-summary-low-ancient-face ((t (:foreground "SkyBlue" :italic t))))
     (gnus-summary-normal-ancient-face ((t (:foreground "SkyBlue"))))
     (gnus-summary-high-unread-face ((t (:bold t))))
     (gnus-summary-low-unread-face ((t (:italic t))))
     (gnus-summary-normal-unread-face ((t (nil))))
     (gnus-summary-high-read-face ((t (:foreground "PaleGreen" :bold t))))
     (gnus-summary-low-read-face ((t (:foreground "PaleGreen" :italic t))))
     (gnus-summary-normal-read-face ((t (:foreground "PaleGreen"))))
     (gnus-splash-face ((t (:foreground "Brown"))))
     (eshell-ls-directory-face ((t (:foreground "SkyBlue" :bold t))))
     (eshell-ls-symlink-face ((t (:foreground "Cyan" :bold t))))
     (eshell-ls-executable-face ((t (:foreground "Green" :bold t))))
     (eshell-ls-readonly-face ((t (:foreground "Pink"))))
     (eshell-ls-unreadable-face ((t (:foreground "DarkGrey"))))
     (eshell-ls-special-face ((t (:foreground "Magenta" :bold t))))
     (eshell-ls-missing-face ((t (:foreground "Red" :bold t))))
     (eshell-ls-archive-face ((t (:foreground "Orchid" :bold t))))
     (eshell-ls-backup-face ((t (:foreground "LightSalmon"))))
     (eshell-ls-product-face ((t (:foreground "LightSalmon"))))
     (eshell-ls-clutter-face ((t (:foreground "OrangeRed" :bold t))))
     (eshell-prompt-face ((t (:foreground "Pink" :bold t))))
     (term-default-fg ((t (nil))))
     (term-default-bg ((t (nil))))
     (term-default-fg-inv ((t (nil))))
     (term-default-bg-inv ((t (nil))))
     (term-bold ((t (:bold t))))
     (term-underline ((t (:underline t))))
     (term-invisible ((t (nil))))
     (term-invisible-inv ((t (nil))))
     (term-black ((t (:foreground "black"))))
     (term-red ((t (:foreground "red"))))
     (term-green ((t (:foreground "green"))))
     (term-yellow ((t (:foreground "yellow"))))
     (term-blue ((t (:foreground "blue"))))
     (term-magenta ((t (:foreground "magenta"))))
     (term-cyan ((t (:foreground "cyan"))))
     (term-white ((t (:foreground "white"))))
     (term-blackbg ((t (:background "black"))))
     (term-redbg ((t (:background "red"))))
     (term-greenbg ((t (:background "green"))))
     (term-yellowbg ((t (:background "yellow"))))
     (term-bluebg ((t (:background "blue"))))
     (term-magentabg ((t (:background "magenta"))))
     (term-cyanbg ((t (:background "cyan"))))
     (term-whitebg ((t (:background "white"))))
     (gnus-emphasis-bold ((t (:bold t))))
     (gnus-emphasis-italic ((t (:italic t))))
     (gnus-emphasis-underline ((t (:underline t))))
     (gnus-emphasis-underline-bold ((t (:bold t :underline t))))
     (gnus-emphasis-underline-italic ((t (:italic t :underline t))))
     (gnus-emphasis-bold-italic ((t (:bold t :italic t))))
     (gnus-emphasis-underline-bold-italic ((t (:bold t :italic t :underline t))))
     (gnus-emphasis-highlight-words ((t (:foreground "yellow" :background "black"))))
     (gnus-signature-face ((t (:italic t))))
     (gnus-header-from-face ((t (:foreground "spring green"))))
     (gnus-header-subject-face ((t (:foreground "yellow" :bold t))))
     (gnus-header-newsgroups-face ((t (:foreground "SeaGreen3" :bold t :italic t))))
     (gnus-header-name-face ((t (:foreground "pink"))))
     (gnus-header-content-face ((t (:foreground "lime green" :italic t))))
     (gnus-cite-attribution-face ((t (:italic t))))
     (gnus-cite-face-1 ((t (:foreground "light blue"))))
     (gnus-cite-face-2 ((t (:foreground "light cyan"))))
     (gnus-cite-face-3 ((t (:foreground "light yellow"))))
     (gnus-cite-face-4 ((t (:foreground "light pink"))))
     (gnus-cite-face-5 ((t (:foreground "pale green"))))
     (gnus-cite-face-6 ((t (:foreground "beige"))))
     (gnus-cite-face-7 ((t (:foreground "orange"))))
     (gnus-cite-face-8 ((t (:foreground "magenta"))))
     (gnus-cite-face-9 ((t (:foreground "violet"))))
     (gnus-cite-face-10 ((t (:foreground "medium purple"))))
     (gnus-cite-face-11 ((t (:foreground "turquoise")))))))

(defun color-theme-sitaramv-nt (&optional preview)
  "Black foreground on white background.
Includes faces for font-lock, widget, custom, speedbar."
  (interactive)
  (color-theme-install preview
   '(((foreground-color . "black")
      (background-color . "white")
      (mouse-color . "sienna3")
      (cursor-color . "HotPink")
      (border-color . "Blue")
      (background-mode . light))
     (default ((t (nil))))
     (modeline ((t (:foreground "black" :background "gold2"))))
     (highlight ((t (:foreground "black" :background "darkseagreen2"))))
     (bold ((t (:bold t))))
     (italic ((t (:italic t))))
     (bold-italic ((t (:bold t :italic t))))
     (region ((t (:foreground "black" :background "snow3"))))
     (secondary-selection ((t (:background "paleturquoise"))))
     (underline ((t (:underline t))))
     (lazy-highlight-face ((t (:foreground "dark magenta" :bold t))))
     (font-lock-comment-face ((t (:foreground "ForestGreen" :italic t))))
     (font-lock-string-face ((t (:foreground "red"))))
     (font-lock-keyword-face ((t (:foreground "blue" :bold t))))
     (font-lock-builtin-face ((t (:foreground "black"))))
     (font-lock-function-name-face ((t (:foreground "dark magenta" :bold t))))
     (font-lock-variable-name-face ((t (:foreground "black"))))
     (font-lock-type-face ((t (:foreground "blue"))))
     (font-lock-constant-face ((t (:foreground "CadetBlue"))))
     (font-lock-warning-face ((t (:foreground "Red" :bold t))))
     (widget-documentation-face ((t (:foreground "dark green"))))
     (widget-button-face ((t (:bold t))))
     (widget-field-face ((t (:background "gray85"))))
     (widget-single-line-field-face ((t (:background "gray85"))))
     (widget-inactive-face ((t (:foreground "dim gray"))))
     (widget-button-pressed-face ((t (:foreground "red"))))
     (custom-invalid-face ((t (:foreground "yellow" :background "red"))))
     (custom-rogue-face ((t (:foreground "pink" :background "black"))))
     (custom-modified-face ((t (:foreground "white" :background "blue"))))
     (custom-set-face ((t (:foreground "blue" :background "white"))))
     (custom-changed-face ((t (:foreground "white" :background "blue"))))
     (custom-saved-face ((t (:underline t))))
     (custom-button-face ((t (nil))))
     (custom-documentation-face ((t (nil))))
     (custom-state-face ((t (:foreground "dark green"))))
     (custom-variable-tag-face ((t (:foreground "blue" :underline t))))
     (custom-variable-button-face ((t (:bold t :underline t))))
     (custom-face-tag-face ((t (:underline t))))
     (custom-group-tag-face-1 ((t (:foreground "red" :underline t))))
     (custom-group-tag-face ((t (:foreground "blue" :underline t))))
     (speedbar-button-face ((t (:foreground "green4"))))
     (speedbar-file-face ((t (:foreground "cyan4"))))
     (speedbar-directory-face ((t (:foreground "blue4"))))
     (speedbar-tag-face ((t (:foreground "brown"))))
     (speedbar-selected-face ((t (:foreground "red" :underline t))))
     (speedbar-highlight-face ((t (:background "green"))))
     (ff-paths-non-existant-file-face ((t (:foreground "NavyBlue" :bold t))))
     (show-paren-match-face ((t (:background "light blue"))))
     (show-paren-mismatch-face ((t (:foreground "white" :background "purple")))))))

(defun color-theme-billw (&optional preview)
  "Cornsilk on black.
Includes info, diary, font-lock, eshell, w3, sgml, message, gnus,
widget, custom, latex, ediff."
  (interactive)
  (color-theme-install preview
   '(((foreground-color . "cornsilk")
      (background-color . "black")
      (mouse-color . "black")
      (cursor-color . "white")
      (border-color . "black")
      (background-mode . dark))
     (default ((t (nil))))
     (modeline ((t (:foreground "black" :background "wheat"))))
     (highlight ((t (:foreground "wheat" :background "darkslategray"))))
     (bold ((t (:bold t))))
     (italic ((t (:italic t))))
     (bold-italic ((t (:bold t :italic t))))
     (region ((t (:background "dimgray"))))
     (secondary-selection ((t (:background "deepskyblue4"))))
     (underline ((t (:underline t))))
     (info-node ((t (:foreground "yellow" :bold t :italic t))))
     (info-menu-5 ((t (:underline t))))
     (info-xref ((t (:foreground "yellow" :bold t))))
     (diary-face ((t (:foreground "orange"))))
     (calendar-today-face ((t (:underline t))))
     (holiday-face ((t (:background "red"))))
     (show-paren-match-face ((t (:background "deepskyblue4"))))
     (show-paren-mismatch-face ((t (:foreground "white" :background "red"))))
     (font-lock-comment-face ((t (:foreground "gold"))))
     (font-lock-string-face ((t (:foreground "orange"))))
     (font-lock-keyword-face ((t (:foreground "cyan1"))))
     (font-lock-builtin-face ((t (:foreground "LightSteelBlue"))))
     (font-lock-function-name-face ((t (:foreground "mediumspringgreen"))))
     (font-lock-variable-name-face ((t (:foreground "light salmon"))))
     (font-lock-type-face ((t (:foreground "yellow1"))))
     (font-lock-constant-face ((t (:foreground "salmon"))))
     (font-lock-warning-face ((t (:foreground "gold" :bold t))))
     (blank-space-face ((t (:background "LightGray"))))
     (blank-tab-face ((t (:foreground "black" :background "cornsilk"))))
     (highline-face ((t (:background "gray35"))))
     (eshell-ls-directory-face ((t (:foreground "green" :bold t))))
     (eshell-ls-symlink-face ((t (:foreground "Cyan" :bold t))))
     (eshell-ls-executable-face ((t (:foreground "orange" :bold t))))
     (eshell-ls-readonly-face ((t (:foreground "gray"))))
     (eshell-ls-unreadable-face ((t (:foreground "DarkGrey"))))
     (eshell-ls-special-face ((t (:foreground "Magenta" :bold t))))
     (eshell-ls-missing-face ((t (:foreground "Red" :bold t))))
     (eshell-ls-archive-face ((t (:foreground "Orchid" :bold t))))
     (eshell-ls-backup-face ((t (:foreground "LightSalmon"))))
     (eshell-ls-product-face ((t (:foreground "LightSalmon"))))
     (eshell-ls-clutter-face ((t (:foreground "blue" :bold t))))
     (w3-style-face-00026 ((t (:foreground "#fff000"))))
     (w3-style-face-00025 ((t (:foreground "#4ff2b4"))))
     (w3-style-face-00024 ((t (:foreground "yellow"))))
     (w3-style-face-00023 ((t (:foreground "#8ffeeb"))))
     (w3-style-face-00022 ((t (:foreground "#6ffacd"))))
     (w3-style-face-00019 ((t (:foreground "#fff000"))))
     (w3-style-face-00021 ((t (:foreground "#6ffacd"))))
     (w3-style-face-00018 ((t (:foreground "yellow"))))
     (w3-style-face-00020 ((t (:foreground "#bff222"))))
     (w3-style-face-00016 ((t (:foreground "#bff222"))))
     (w3-style-face-00015 ((t (:foreground "#fff000"))))
     (w3-style-face-00014 ((t (:foreground "yellow"))))
     (w3-style-face-00013 ((t (:foreground "#bff222"))))
     (w3-style-face-00012 ((t (:foreground "#fff000"))))
     (w3-style-face-00009 ((t (:foreground "#bff222"))))
     (w3-style-face-00011 ((t (:foreground "#0ff080"))))
     (w3-style-face-00010 ((t (:foreground "#0ff080"))))
     (w3-style-face-00008 ((t (nil))))
     (w3-style-face-00007 ((t (nil))))
     (w3-style-face-00006 ((t (:foreground "#ffff00"))))
     (w3-style-face-00004 ((t (nil))))
     (w3-style-face-00003 ((t (:underline t))))
     (w3-style-face-00002 ((t (:foreground "#b22222" :underline t))))
     (w3-style-face-00001 ((t (:foreground "#ff0000" :underline t))))
     (w3-style-face-00000 ((t (nil))))
     (sgml-start-tag-face ((t (:foreground "mediumspringgreen"))))
     (custom-button-face ((t (:foreground "white"))))
     (sgml-ignored-face ((t (:foreground "gray20" :background "gray60"))))
     (sgml-doctype-face ((t (:foreground "orange"))))
     (sgml-sgml-face ((t (:foreground "yellow"))))
     (vc-annotate-face-0046FF ((t (:foreground "wheat" :background "black"))))
     (custom-documentation-face ((t (:foreground "white"))))
     (sgml-end-tag-face ((t (:foreground "greenyellow"))))
     (linemenu-face ((t (:background "gray30"))))
     (sgml-entity-face ((t (:foreground "gold"))))
     (w3-style-face-00044 ((t (:foreground "#6affcd"))))
     (w3-style-face-00041 ((t (:foreground "#b2ff22"))))
     (w3-style-face-00038 ((t (:foreground "#b2ff22"))))
     (w3-style-face-00040 ((t (:foreground "#ffff00"))))
     (w3-style-face-00037 ((t (:foreground "#ffff00"))))
     (w3-style-face-00034 ((t (:foreground "#ffff00"))))
     (w3-style-face-00033 ((t (:foreground "#b2ff22"))))
     (w3-style-face-00032 ((t (:foreground "#ffff00"))))
     (w3-style-face-00029 ((t (:foreground "#ffff00"))))
     (w3-style-face-00030 ((t (:foreground "#b2ff22"))))
     (message-header-to-face ((t (:foreground "floral white" :bold t))))
     (message-header-cc-face ((t (:foreground "ivory"))))
     (message-header-subject-face ((t (:foreground "papaya whip" :bold t))))
     (message-header-newsgroups-face ((t (:foreground "lavender blush" :bold t :italic t))))
     (message-header-other-face ((t (:foreground "pale turquoise"))))
     (message-header-name-face ((t (:foreground "light sky blue"))))
     (message-header-xheader-face ((t (:foreground "blue"))))
     (message-separator-face ((t (:foreground "sandy brown"))))
     (message-cited-text-face ((t (:foreground "plum1"))))
     (message-mml-face ((t (:foreground "ForestGreen"))))
     (gnus-group-news-1-face ((t (:foreground "white" :bold t))))
     (gnus-group-news-1-empty-face ((t (:foreground "white"))))
     (gnus-group-news-2-face ((t (:foreground "lightcyan" :bold t))))
     (gnus-group-news-2-empty-face ((t (:foreground "lightcyan"))))
     (gnus-group-news-3-face ((t (:foreground "tan" :bold t))))
     (gnus-group-news-3-empty-face ((t (:foreground "tan"))))
     (gnus-group-news-4-face ((t (:foreground "white" :bold t))))
     (gnus-group-news-4-empty-face ((t (:foreground "white"))))
     (gnus-group-news-5-face ((t (:foreground "wheat" :bold t))))
     (gnus-group-news-5-empty-face ((t (:foreground "wheat"))))
     (gnus-group-news-6-face ((t (:foreground "tan" :bold t))))
     (gnus-group-news-6-empty-face ((t (:foreground "tan"))))
     (gnus-group-news-low-face ((t (:foreground "DarkTurquoise" :bold t))))
     (gnus-group-news-low-empty-face ((t (:foreground "DarkTurquoise"))))
     (gnus-group-mail-1-face ((t (:foreground "white" :bold t))))
     (gnus-group-mail-1-empty-face ((t (:foreground "gray80"))))
     (gnus-group-mail-2-face ((t (:foreground "lightcyan" :bold t))))
     (gnus-group-mail-2-empty-face ((t (:foreground "lightcyan"))))
     (gnus-group-mail-3-face ((t (:foreground "tan" :bold t))))
     (gnus-group-mail-3-empty-face ((t (:foreground "tan"))))
     (gnus-group-mail-low-face ((t (:foreground "aquamarine4" :bold t))))
     (gnus-group-mail-low-empty-face ((t (:foreground "aquamarine4"))))
     (gnus-summary-selected-face ((t (:background "deepskyblue4" :underline t))))
     (gnus-summary-cancelled-face ((t (:foreground "black" :background "gray"))))
     (gnus-summary-high-ticked-face ((t (:foreground "gray70" :bold t))))
     (gnus-summary-low-ticked-face ((t (:foreground "gray70" :bold t))))
     (gnus-summary-normal-ticked-face ((t (:foreground "gray70" :bold t))))
     (gnus-summary-high-ancient-face ((t (:foreground "SkyBlue" :bold t))))
     (gnus-summary-low-ancient-face ((t (:foreground "SkyBlue" :italic t))))
     (gnus-summary-normal-ancient-face ((t (:foreground "SkyBlue"))))
     (gnus-summary-high-unread-face ((t (:bold t))))
     (gnus-summary-low-unread-face ((t (:italic t))))
     (gnus-summary-normal-unread-face ((t (nil))))
     (gnus-summary-high-read-face ((t (:foreground "PaleGreen" :bold t))))
     (gnus-summary-low-read-face ((t (:foreground "PaleGreen" :italic t))))
     (gnus-summary-normal-read-face ((t (:foreground "PaleGreen"))))
     (gnus-splash-face ((t (:foreground "gold"))))
     (font-latex-bold-face ((t (nil))))
     (font-latex-italic-face ((t (nil))))
     (font-latex-math-face ((t (nil))))
     (font-latex-sedate-face ((t (:foreground "Gray85"))))
     (font-latex-string-face ((t (:foreground "orange"))))
     (font-latex-warning-face ((t (:foreground "gold"))))
     (widget-documentation-face ((t (:foreground "lime green"))))
     (widget-button-face ((t (:bold t))))
     (widget-field-face ((t (:background "gray20"))))
     (widget-single-line-field-face ((t (:background "gray20"))))
     (widget-inactive-face ((t (:foreground "wheat"))))
     (widget-button-pressed-face ((t (:foreground "red"))))
     (custom-invalid-face ((t (:foreground "yellow" :background "red"))))
     (custom-rogue-face ((t (:foreground "pink" :background "black"))))
     (custom-modified-face ((t (:foreground "white" :background "blue"))))
     (custom-set-face ((t (:foreground "blue"))))
     (custom-changed-face ((t (:foreground "wheat" :background "skyblue"))))
     (custom-saved-face ((t (:underline t))))
     (custom-state-face ((t (:foreground "light green"))))
     (custom-variable-tag-face ((t (:foreground "skyblue" :underline t))))
     (custom-variable-button-face ((t (:bold t :underline t))))
     (custom-face-tag-face ((t (:foreground "white" :underline t))))
     (custom-group-tag-face-1 ((t (:foreground "pink" :underline t))))
     (custom-group-tag-face ((t (:foreground "skyblue" :underline t))))
     (swbuff-current-buffer-face ((t (:foreground "red" :bold t))))
     (ediff-current-diff-face-A ((t (:foreground "firebrick" :background "pale green"))))
     (ediff-current-diff-face-B ((t (:foreground "DarkOrchid" :background "Yellow"))))
     (ediff-current-diff-face-C ((t (:foreground "white" :background "indianred"))))
     (ediff-current-diff-face-Ancestor ((t (:foreground "Black" :background "VioletRed"))))
     (ediff-fine-diff-face-A ((t (:foreground "Navy" :background "sky blue"))))
     (ediff-fine-diff-face-B ((t (:foreground "Black" :background "cyan"))))
     (ediff-fine-diff-face-C ((t (:foreground "Black" :background "Turquoise"))))
     (ediff-fine-diff-face-Ancestor ((t (:foreground "Black" :background "Green"))))
     (ediff-even-diff-face-A ((t (:foreground "Black" :background "light grey"))))
     (ediff-even-diff-face-B ((t (:foreground "White" :background "Grey"))))
     (ediff-even-diff-face-C ((t (:foreground "Black" :background "light grey"))))
     (ediff-even-diff-face-Ancestor ((t (:foreground "White" :background "Grey"))))
     (ediff-odd-diff-face-A ((t (:foreground "White" :background "Grey"))))
     (ediff-odd-diff-face-B ((t (:foreground "Black" :background "light grey"))))
     (ediff-odd-diff-face-C ((t (:foreground "White" :background "Grey"))))
     (ediff-odd-diff-face-Ancestor ((t (:foreground "Black" :background "light grey"))))
     (gnus-emphasis-bold ((t (:bold t))))
     (gnus-emphasis-italic ((t (:italic t))))
     (gnus-emphasis-underline ((t (:foreground "white" :background "goldenrod4"))))
     (gnus-emphasis-underline-bold ((t (:foreground "black" :background "yellow" :bold t :underline t))))
     (gnus-emphasis-underline-italic ((t (:foreground "black" :background "yellow" :italic t :underline t))))
     (gnus-emphasis-bold-italic ((t (:bold t :italic t))))
     (gnus-emphasis-underline-bold-italic ((t (:foreground "black" :background "yellow" :bold t :italic t :underline t))))
     (gnus-emphasis-highlight-words ((t (:foreground "yellow" :background "black"))))
     (gnus-signature-face ((t (:italic t))))
     (gnus-header-from-face ((t (:foreground "wheat"))))
     (gnus-header-subject-face ((t (:foreground "wheat" :bold t))))
     (gnus-header-newsgroups-face ((t (:foreground "wheat" :italic t))))
     (gnus-header-name-face ((t (:foreground "white"))))
     (gnus-header-content-face ((t (:foreground "tan" :italic t))))
     (gnus-filterhist-face-1 ((t (nil))))
     (gnus-splash ((t (:foreground "Brown"))))
     (gnus-cite-attribution-face ((t (:italic t))))
     (gnus-cite-face-1 ((t (:foreground "light blue"))))
     (gnus-cite-face-2 ((t (:foreground "light cyan"))))
     (gnus-cite-face-3 ((t (:foreground "light yellow"))))
     (gnus-cite-face-4 ((t (:foreground "light pink"))))
     (gnus-cite-face-5 ((t (:foreground "pale green"))))
     (gnus-cite-face-6 ((t (:foreground "beige"))))
     (gnus-cite-face-7 ((t (:foreground "orange"))))
     (gnus-cite-face-8 ((t (:foreground "magenta"))))
     (gnus-cite-face-9 ((t (:foreground "violet"))))
     (gnus-cite-face-10 ((t (:foreground "medium purple"))))
     (gnus-cite-face-11 ((t (:foreground "turquoise")))))))

(defun color-theme-retro-green (&optional preview color)
  "Plain green on black faces for those longing for the good old days."
  (interactive)
  ;; Build a list of faces without parameters
  (let ((old-faces (face-list))
	(faces)
	(face)
	(foreground (or color "green")))
    (while old-faces
      (setq face (car old-faces)
	    old-faces (cdr old-faces))
      (cond ((memq face '(bold bold-italic))
	     (add-to-list 'faces `(,face (( t (:bold t))))))
	    ((memq face '(italic underline show-paren-mismatch-face))
	     (add-to-list 'faces `(,face (( t (:underline t))))))
	    ((memq face '(modeline highlight region secondary-selection 
				   show-paren-match-face))
	     (add-to-list 'faces `(,face (( t (:inverse t))))))
	    (t
	     (add-to-list 'faces `(,face (( t (nil))))))))
    (color-theme-install 
     preview
     (cons (list (cons 'foreground-color foreground)
		 (cons 'background-color "black")
		 (cons 'mouse-color foreground)
		 (cons 'cursor-color foreground)
		 (cons 'border-color foreground)
		 (cons 'background-mode 'dark))
	   faces))))

(defun color-theme-retro-orange (&optional preview)
  "Plain orange on black faces for those longing for the good old days."
  (interactive)
  (color-theme-retro-green t "orange"))

(provide 'color-theme)

;;; colors.el ends here
